#
# spec file for package janet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global somajor 1
%global sominor 30
%global libname libjanet%{somajor}_%{sominor}

Name:           janet
Version:        %{somajor}.%{sominor}.0
Release:        1.1
Summary:        Lisp-like functional and imperative programming language
License:        MIT
URL:            https://janet-lang.org
Source0:        https://github.com/janet-lang/janet/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  ninja

%description
Janet is a functional and imperative programming language.
The entire language (core library, interpreter, compiler, assembler,
PEG) is less than 2MB.
Janet scripting can be added to an application by embedding a single
C source file and a single header.

%package -n %{libname}
Summary:        Lisp-like functional and imperative programming language
Group:          System/Libraries

%description -n %{libname}
Janet is a functional and imperative programming language.

%package devel
Summary:        Headers for embedding Janet scripting
Group:          Development/Languages/C and C++
Requires:       %{libname} = %{version}

%description devel
Janet is a functional and imperative programming language.
Janet scripting can be added to an application by embedding a single
C source file and a single header.

%prep
%autosetup

%build
export CFLAGS="%optflags -ffat-lto-objects"
%meson -Ddefault_library=shared
%meson_build

%install
export CFLAGS="%optflags -ffat-lto-objects"
%meson_install

# Remove useless keep file
rm %{buildroot}%{_libdir}/janet/.keep

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%{_bindir}/janet
%dir %{_libdir}/janet/
%{_mandir}/man1/janet.1%{?ext_man}
%license LICENSE
%doc *.md

%files devel
%dir %{_libdir}/janet
%dir %{_includedir}/janet
%{_includedir}/janet.h
%{_includedir}/janet/janet.h
%{_libdir}/pkgconfig/janet.pc
%{_libdir}/libjanet.so

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{somajor}*

%changelog
* Sat Aug 26 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.30.0:
  Changes in 1.30.0:
  - Change indexing of `array/remove` to start from -1 at the end instead of -2.
  - Add new string escape sequences `\\a`, `\\b`, `\\?`, and `\\'`.
  - Fix bug with marshalling channels
  - Add `div` for floored division
  - Make `div` and `mod` variadic
  - Support `bnot` for integer types.
  - Define `(mod x 0)` as `x`
  - Add `ffi/pointer-cfunction` to convert pointers to cfunctions
  Changes since 1.29.1:
  - Add support for passing booleans to PEGs for "always" and "never" matching.
  - Allow dictionary types for `take` and `drop`
  - Fix bug with closing channels while other fibers were waiting on them - `ev/take`, `ev/give`, and `ev/select`  will now return the correct (documented) value when another fiber closes the channel.
  - Add `ffi/calling-conventions` to show all available calling conventions for FFI.
  - Add `net/setsockopt`
  - Add `signal` argument to `os/proc-kill` to send signals besides `SIGKILL` on Posix.
  - Add `source` argument to `os/clock` to get different time sources.
  - Various combinator functions now are variadic like `map`
  - Add `file/lines` to iterate over lines in a file lazily.
  - Reorganize test suite to be sorted by module rather than pseudo-randomly.
  - Add `*task-id*`
  - Add `env` argument to `fiber/new`.
  - Add `JANET_NO_AMALG` flag to Makefile to properly incremental builds
  - Optimize bytecode compiler to generate fewer instructions and improve loops.
  - Fix bug with `ev/gather` and hung fibers.
  - Add `os/isatty`
  - Add `has-key?` and `has-value?`
  - Make imperative arithmetic macros variadic
  - `ev/connect` now yields to the event loop instead of blocking while waiting for an ACK.
* Mon May 29 2023 Jan Engelhardt <jengelh@inai.de>
- Fix errors, trim, and wrap description.
* Sat May 27 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.28.0:
  * Various bug fixes
  * Make nested short-fn's behave a bit more predictably (it is still not recommended to nest short-fns).
  * Add os/strftime for date formatting.
  * Fix ev/select on threaded channels sometimes live-locking.
  * Support the NO_COLOR environment variable to turn off VT100 color codes in repl (and in scripts).
  * See http://no-color.org/
  * Disallow using (splice x) in contexts where it doesn't make sense rather than silently coercing to x.
  * Instead, raise a compiler error.
  * Change the names of :user8 and :user9 sigals to :interrupt and :await
  * Change the names of :user8 and :user9 fiber statuses to :interrupted and :suspended.
  * Add ev/all-tasks to see all currently suspended fibers.
  * Add keep-syntax and keep-syntax! functions to make writing macros easier.
* Sat Mar  4 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for janet 1.26.0
